/////////////////////////////////////////////////////////////////////////////
// NAME: irq.c
// FUNKTION: Enthlt die Interrupt Service Routinen
// ERSTELLT: 02/2004 - Erwin Baeck
/////////////////////////////////////////////////////////////////////////////

#include <mega16.h>
#include "globals.h"

//---------------------------------------------------------------------------
// Globals
//---------------------------------------------------------------------------
UWORD giMSecTimer;
UWORD gADCData;
bit gADCComplete;

//---------------------------------------------------------------------------
// External Interrupt 0 service routine
//---------------------------------------------------------------------------
interrupt [EXT_INT0] void ext_int0_isr(void)
{
// Place your code here

}

//---------------------------------------------------------------------------
// External Interrupt 1 service routine
//---------------------------------------------------------------------------
interrupt [EXT_INT1] void ext_int1_isr(void)
{
// Place your code here

}

//---------------------------------------------------------------------------
// External Interrupt 2 service routine
//---------------------------------------------------------------------------
interrupt [EXT_INT2] void ext_int2_isr(void)
{
// Place your code here

}

#define RXB8 1
#define TXB8 0
#define UPE 2
#define OVR 3
#define FE 4
#define UDRE 5
#define RXC 7

#define FRAMING_ERROR (1<<FE)
#define PARITY_ERROR (1<<UPE)
#define DATA_OVERRUN (1<<OVR)
#define DATA_REGISTER_EMPTY (1<<UDRE)
#define RX_COMPLETE (1<<RXC)

//---------------------------------------------------------------------------
// USART Receiver buffer
//---------------------------------------------------------------------------
#define RX_BUFFER_SIZE 248
char rx_buffer[RX_BUFFER_SIZE];
unsigned char rx_wr_index,rx_rd_index,rx_counter;

//---------------------------------------------------------------------------
// This flag is set on USART Receiver buffer overflow
//---------------------------------------------------------------------------
bit rx_buffer_overflow;

//---------------------------------------------------------------------------
// USART Receiver interrupt service routine
//---------------------------------------------------------------------------
#pragma savereg-
interrupt [USART_RXC] void uart_rx_isr(void)
{
char status,data;
#asm
    push r26
    push r27
    push r30
    push r31
    in   r26,sreg
    push r26
#endasm
status=UCSRA;
data=UDR;

if ((status & (FRAMING_ERROR | PARITY_ERROR | DATA_OVERRUN))==0)
   {
   rx_buffer[rx_wr_index]=data;
   if (++rx_wr_index == RX_BUFFER_SIZE) rx_wr_index=0;
   if (++rx_counter == RX_BUFFER_SIZE)
      {
      rx_counter=0;
      rx_buffer_overflow=1;
      };
   };
#asm
    pop  r26
    out  sreg,r26
    pop  r31
    pop  r30
    pop  r27
    pop  r26
#endasm
}
#pragma savereg+

#ifndef _DEBUG_TERMINAL_IO_
//---------------------------------------------------------------------------
// Get a character from the USART Receiver buffer
//---------------------------------------------------------------------------
#define _ALTERNATE_GETCHAR_
#pragma used+
char getchar(void)
{
char data;
while (rx_counter==0);
data=rx_buffer[rx_rd_index];
if (++rx_rd_index == RX_BUFFER_SIZE) rx_rd_index=0;
#asm("cli")
--rx_counter;
#asm("sei")
return data;
}
#pragma used-
#endif

//---------------------------------------------------------------------------
// Standard Input/Output functions
//---------------------------------------------------------------------------
#include <stdio.h>

//===========================================================================
// Timer 0 overflow interrupt service routine
//===========================================================================
interrupt [TIM0_OVF] void timer0_ovf_isr(void)
{
TCNT0 = 0x06;	// reinitialize T0 for a period of 1 msec

giMSecTimer++;
}

//---------------------------------------------------------------------------
// Timer 1 overflow interrupt service routine
//---------------------------------------------------------------------------
interrupt [TIM1_OVF] void timer1_ovf_isr(void)
{
// Place your code here

}

//---------------------------------------------------------------------------
// Timer 2 overflow interrupt service routine
//---------------------------------------------------------------------------
interrupt [TIM2_OVF] void timer2_ovf_isr(void)
{
// Place your code here

}

//---------------------------------------------------------------------------
// ADC interrupt service routine
//---------------------------------------------------------------------------
interrupt [ADC_INT] void adc_isr(void)
{
gADCData = ADCW;
gADCComplete = TRUE;
}

//---------------------------------------------------------------------------
// SPI interrupt service routine
//---------------------------------------------------------------------------
interrupt [SPI_STC] void spi_isr(void)
{
unsigned char data;
data = SPDR;
// Place your code here

}

/////////////////////////////////////////////////////////////////////////////
// Ende von irq.c
/////////////////////////////////////////////////////////////////////////////
